gsap.registerPlugin(ScrollTrigger);
gsap.registerPlugin(Observer);

var isLgSize = window.matchMedia("only screen and (min-width: 1024px)").matches;
var isSm = window.matchMedia("only screen and (min-width: 640px)").matches;

const swiperMainCaracteristicas = document.querySelector('.swyperCaracteristicas');
if (swiperMainCaracteristicas && isLgSize) {
    var swyperCaracteristicas = new Swiper(".swyperCaracteristicas", {
        // direction: "vertical",
        slidesPerView: 1.2,
        spaceBetween: 10,
        slidesPerView: 3,
        spaceBetween: 16,
        direction: "vertical",
        centeredSlides: true,
        slidesPerGroup: 1,
        initialSlide: 0,
    });

    const swiperControl = document.querySelector('.swyperCaracteristicas').swiper;
    const totalSlides = swiperControl.slides.length - 1;
    let isFinal = false;

    let intentObserver = ScrollTrigger.observe({
        type: "wheel,touch",
        onUp: () => !isFinal && nextSlideMe(),
        onDown: () => prevSlideMe(),
        wheelSpeed: -1,
        tolerance: 500,
        preventDefault: true,
        onPress: self => {
            // on touch devices like iOS, if we want to prevent scrolling, we must call preventDefault() on the touchstart (Observer doesn't do that because that would also prevent side-scrolling which is undesirable in most cases)
            ScrollTrigger.isTouch && self.event.preventDefault()
        }
    })
    intentObserver.disable();


    let preventScroll = ScrollTrigger.observe({
        preventDefault: true,
        type: "wheel,scroll",
        allowClicks: true,
        onEnable: self => self.savedScroll = self.scrollY(), // save the scroll position
        onChangeY: self => self.scrollY(self.savedScroll)    // refuse to scroll
    });
    preventScroll.disable();


    function nextSlideMe() {
        swiperControl.slideNext();
        if (swiperControl.realIndex == totalSlides) {
            intentObserver.disable();
            preventScroll.disable();
            isFinal = true;
        }
    }

    function prevSlideMe() {
        swiperControl.slidePrev();
        if (swiperControl.realIndex == 0) {
            intentObserver.disable();
            preventScroll.disable();
        }
    }

    ScrollTrigger.create({
        trigger: "#targeSlider",
        pin: true,
        anticipatePin: true,
        // start: "50% 50%",
        // end: "+=1",
        start: "top top",
        end: "+=50% 80%",
        // markers: true,
        pinSpacing: true,
        onEnter: (self) => {
            if (preventScroll.isEnabled === false && !isFinal) {
                self.scroll(self.start);
                preventScroll.enable();
                intentObserver.enable();
            }
        },
        onEnterBack: () => {
            if (preventScroll.isEnabled === false) {
                self.scroll(self.start);
                preventScroll.enable();
                intentObserver.enable();
                isFinal = false;
            }
        }
    });
}

var swyperInfoDescubre = new Swiper(".swyperInfoDescubre", {
    slidesPerView: 1,
    spaceBetween: 10,
    breakpoints: {
        640: {
            slidesPerView: 2,
            spaceBetween: 20,
        },
        768: {
            slidesPerView: 3,
            spaceBetween: 20,
        },
        1024: {
            slidesPerView: 4,
            spaceBetween: 16,
        },
    },
    pagination: {
        el: ".pagination-descubre",
        clickable: true,
    },
});

var swyperCaracteristicasMobile = new Swiper(".swyperCaracteristicasMobile", {
    // direction: "vertical",
    slidesPerView: 1.2,
    spaceBetween: 10,
    breakpoints: {
        640: {
            slidesPerView: 2,
            spaceBetween: 20,
        },
        768: {
            slidesPerView: 3,
            spaceBetween: 20,
        },
        1024: {
            slidesPerView: 3,
            spaceBetween: 16,
        },
    },
    pagination: {
        el: ".pagination-caracteristicas",
        clickable: true,
    },
});

const titlesBanner = [...document.querySelectorAll('.title-banner-animated')];
const titlesAnimated = [...document.querySelectorAll('.text-animated-title')];
const textAnimated = [...document.querySelectorAll('.text-animated')];
const opacityText = [...document.querySelectorAll('.text-opacity-animated')];
const opacityTextBanner = [...document.querySelectorAll('.text-banner-opacity')];

titlesBanner.forEach(title => {
    new SplitType(title, {
        types: "lines, words",
        lineClass: "word-line"
    });
    const words = title.querySelectorAll('.word');
    gsap.set(words, {
        y: "80px"
    });
});

titlesAnimated.forEach(title => {
    new SplitType(title, {
        types: "lines, words",
        lineClass: "word-line"
    });
    const words = title.querySelectorAll('.word');
    gsap.fromTo(words, {
        y: "80px",
        stagger: 0.03,
    }, {
        ease: "expo.out",
        y: 0,
        duration: 1,
        scrollTrigger: {
            trigger: title,
            start: "top 80%",
            end: "top 80%",
            markers: false
        }
    });
});

textAnimated.forEach(title => {
    new SplitType(title, {
        types: "lines, words",
        lineClass: "word-line"
    });
    const words = title.querySelectorAll('.word');
    gsap.fromTo(words, {
        y: "80px",
        stagger: 0.03,
    }, {
        ease: "expo.out",
        y: 0,
        duration: 1,
        scrollTrigger: {
            trigger: title,
            start: "top 80%",
            end: "top 80%",
            markers: false
        }
    });
});

opacityText.forEach(text => {
    gsap.fromTo(text, {
        opacity: 0,
        y: "16px"
    }, {
        opacity: 1,
        ease: "expo.inOut",
        duration: 1,
        y: 0,
        scrollTrigger: {
            trigger: text,
            start: "top 80%",
            end: "top 80%",
            markers: false
        }
    })
});


window.onload = (event) => {
    let delayTitle = 0;
    titlesBanner.forEach(title => {
        new SplitType(title, {
            types: "lines, words",
            lineClass: "word-line"
        });
        const words = title.querySelectorAll('.word');
        gsap.fromTo(words, {
            y: "80px",
            stagger: 0.03,
        }, {
            ease: "expo.out",
            y: 0,
            duration: 2,
            delay: delayTitle
        });
        delayTitle += 0.6;
    });
    opacityTextBanner.forEach(title => {
        const delayAttr = title.getAttribute("data-delay");
        gsap.to(title, {
            opacity: 1,
            ease: "power2.inOut",
            duration: 1,
            y: 0,
            delay: delayAttr
        });
    });
    const hiddenElements = document.querySelectorAll('.hidden-pan');
    hiddenElements.forEach(element => {
        element.style.opacity = 1;
    })
    animatedBannerHome();
    animatedBannerIntegral();
    animatedBannerCrebollos();
    animatedBannerCrejochos();
};

function animatedBannerHome() {
    const breadCenter = document.querySelector('#breadCenter');
    if (!breadCenter)
        return;
    gsap.fromTo(breadCenter, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2
    });
    const priceDesk = document.querySelector('#priceDesk');
    gsap.fromTo(priceDesk, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2,
        delay: 0.6
    });

    const bread1 = document.getElementById('bread1');
    const bread2 = document.querySelector('#bread2');
    const bread3 = document.querySelector('#bread3');
    const bread4 = document.querySelector('#bread4');
    const trigo1 = document.querySelector('#trigo1');
    const trigo2 = document.querySelector('#trigo2');

    const topBread2 = (isLgSize) ? "62%" : "48%";
    const bottomBread3 = (isSm) ? "-8%" : "5%";
    const trigo1Bottom = (isLgSize) ? "6%" : "15%";
    const bottomBread4 = (isLgSize) ? "-18%" : "-5%";
    const bottomTrigo2 = (isSm) ? "5%" : "10%";

    var animationTl = gsap.timeline();
    animationTl.fromTo('#imgPanCentro', { y: "0%" }, { y: "10%", duration: 1 });
    animationTl.fromTo(bread1, {
        ease: "power1.inOut",
        x: "20%", top: "100%",
    }, { x: "%0", top: "48%", duration: 1 }, "-=1");
    animationTl.fromTo(bread2, {
        ease: "power1.inOut",
        x: "-20%", top: "100%"
    }, { x: "%0", top: topBread2, duration: 1 }, "-=1");
    animationTl.fromTo(trigo1, {
        ease: "power1.inOut",
        x: "40%", bottom: "-50%"
    }, { x: "%0", bottom: trigo1Bottom, duration: 1 }, "-=0.5");
    animationTl.fromTo(trigo2, {
        ease: "power1.inOut",
        x: "-20%", bottom: "-50%"
    }, { x: "%0", bottom: bottomTrigo2, duration: 1 }, "-=1");
    animationTl.fromTo(bread3, {
        ease: "power1.inOut",
        x: "25%", bottom: "-50%"
    }, { x: "%0", bottom: bottomBread3, duration: 1 }, "-=1");
    animationTl.fromTo(bread4, {
        ease: "power1.inOut",
        x: "-25%", bottom: "-50%"
    }, { x: "%0", bottom: bottomBread4, duration: 1 }, "-=1");

    ScrollTrigger.create({
        animation: animationTl,
        trigger: "#tg-banner",
        scrub: 1,
        pin: true,
        start: "top top",
        end: "+=500",
        markers: false,
        pinSpacing: false
    });
}

function animatedBannerIntegral() {
    const breadCenter = document.querySelector('#breadCenterIntegral');
    if (!breadCenter)
        return;
    gsap.fromTo(breadCenter, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2
    });
    const priceDesk = document.querySelector('#priceDesk');
    gsap.fromTo(priceDesk, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2,
        delay: 0.6
    });

    const bread1 = document.getElementById('bread1');
    const bread2 = document.querySelector('#bread2');
    const bread3 = document.querySelector('#bread3');
    const trigo1 = document.querySelector('#trigo1');
    const trigo2 = document.querySelector('#trigo2');
    const trigo3 = document.querySelector('#trigo3');

    const bottomBread1 = (isSm) ? "28%" : "20%";
    const topBread2 = (isLgSize) ? "46%" : "40%";
    const trigo1Bottom = (isSm) ? "40%" : "34%";

    var animationTl = gsap.timeline();
    animationTl.fromTo('#imgPanCentro', { y: "0%" }, { y: "10%", duration: 1 });
    animationTl.fromTo('#trigoFondo', { y: "100%" }, { y: "0%", opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(bread1, {
        ease: "power1.inOut",
        x: "20%", bottom: "-80%",
    }, { x: "%0", bottom: bottomBread1, duration: 1 });
    animationTl.fromTo(bread2, {
        ease: "power1.inOut",
        x: "-20%", top: "100%"
    }, { x: "%0", top: topBread2, duration: 1 }, "-=1");
    animationTl.fromTo(trigo1, {
        ease: "power1.inOut",
        x: "-20%", bottom: "-50%"
    }, { x: "%0", bottom: trigo1Bottom, duration: 1 }, "-=0.5");
    animationTl.fromTo(trigo2, {
        ease: "power1.inOut",
        x: "20%", bottom: "-50%"
    }, { x: "%0", bottom: "24%", duration: 1 }, "-=1");
    animationTl.fromTo(trigo3, {
        ease: "power1.inOut",
        x: "-20%", bottom: "-50%"
    }, { x: "%0", bottom: "0%", duration: 1 }, "-=1");
    animationTl.fromTo(bread3, {
        ease: "power1.inOut",
        x: "25%", bottom: "-50%"
    }, { x: "%0", bottom: "0%", duration: 1 }, "-=1");

    ScrollTrigger.create({
        animation: animationTl,
        trigger: "#tg-banner",
        scrub: 1,
        pin: true,
        start: "top top",
        end: "+=500",
        markers: false,
        pinSpacing: false
    });
}

function animatedBannerCrebollos() {
    const breadCenter = document.querySelector('#breadCrebollos');
    if (!breadCenter)
        return;
    gsap.fromTo(breadCenter, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2
    });
    const priceDesk = document.querySelector('#priceDesk');
    gsap.fromTo(priceDesk, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2,
        delay: 0.6
    });

    const bread1 = document.getElementById('bread1');
    const bread2 = document.querySelector('#bread2');
    const bread3 = document.querySelector('#bread3');
    const bread4 = document.querySelector('#bread4');
    const trigo1 = document.querySelector('#trigo1');
    const trigo2 = document.querySelector('#trigo2');

    const bottomBread3 = (isSm) ? "10%" : "5%";
    const bottomBread4 = (isSm) ? "-4%" : "-5%";

    var animationTl = gsap.timeline();
    animationTl.fromTo('#imgPanCentro', { y: "0%" }, { y: "10%", duration: 1 });
    animationTl.fromTo('#trigoFondo', { y: "10%" }, { y: "0%", opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(bread1, {
        ease: "power1.inOut", top: "60%",
    }, { top: '20%', duration: 1 });
    animationTl.fromTo(bread2, {
        ease: "power1.inOut",
        top: "60%"
    }, { top: "32%", duration: 1 }, "-=1");
    animationTl.fromTo(trigo1, {
        ease: "power1.inOut",
        opacity: 0,
        bottom: "20%"
    }, { bottom: "10%", x: 0, opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(trigo2, {
        ease: "power1.inOut",
        opacity: 0,
        bottom: "20%"
    }, { bottom: "10%", x: 0, opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(bread3, {
        ease: "power1.inOut", bottom: "-10%",
    }, { bottom: bottomBread3, duration: 1 });
    animationTl.fromTo(bread4, {
        ease: "power1.inOut",
        bottom: "-20%",
    }, { bottom: bottomBread4, duration: 1 }, "-=1");

    ScrollTrigger.create({
        animation: animationTl,
        trigger: "#tg-crebollos",
        scrub: 1,
        pin: true,
        start: "top top",
        end: "+=500",
        markers: false,
        pinSpacing: false
    });
}

let menuMobile = document.querySelector(".modal-menu");
if (menuMobile) {
    document.querySelector('.open-show-menu').addEventListener("click", function (e) {
        e.preventDefault();
        var tl = gsap.timeline();
        tl.add(function () {
            menuMobile.classList.add("open-menu-modal");
            menuMobile.classList.add("open-modal-text");
        });
        tl.to('.text-opacity', { opacity: 1, duration: 0.2, stagger: 0.05 });
    });

    document.querySelector('.close-show-menu').addEventListener("click", function (e) {
        e.preventDefault();
        var tl = gsap.timeline();
        tl.to('.text-opacity', { opacity: 0, duration: 0.2, stagger: 0.05 });
        tl.add(function () {
            menuMobile.classList.remove("open-modal-text");
            menuMobile.classList.remove("open-menu-modal");
        });
    });
}

function animatedBannerCrejochos() {
    const breadCenter = document.querySelector('#breadCrejochos');
    if (!breadCenter)
        return;
    gsap.fromTo(breadCenter, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2
    });
    const priceDesk = document.querySelector('#priceDesk');
    gsap.fromTo(priceDesk, {
        opacity: 0,
        y: 60
    }, {
        opacity: 1,
        y: 0,
        duration: 1.2,
        delay: 0.6
    });

    const bread1 = document.getElementById('bread1');
    const bread2 = document.querySelector('#bread2');
    const bread3 = document.querySelector('#bread3');
    const bread4 = document.querySelector('#bread4');
    const trigo1 = document.querySelector('#trigo1');
    const trigo2 = document.querySelector('#trigo2');
    const trigo3 = document.querySelector('#trigo3');

    const topBread1 = (isLgSize) ? "10%" : "20%";
    const bottomBread3 = (isSm) ? "20%" : "30%";
    const bottomBread4 = (isSm) ? "-4%" : "-5%";
    const bottomTrigo1 = (isSm) ? "32%" : "30%";
    const bottomTrigo3 = (isSm) ? "2%" : "0%";

    var animationTl = gsap.timeline();
    animationTl.fromTo('#imgPanCentro', { y: "0%" }, { y: "10%", duration: 1 });
    animationTl.fromTo(bread1, {
        ease: "power1.inOut", top: "60%",
    }, { top: topBread1, duration: 1 });
    animationTl.fromTo(bread2, {
        ease: "power1.inOut",
        top: "60%",
    }, { top: "32%", duration: 1 }, "-=1");
    animationTl.fromTo(trigo1, {
        ease: "power1.inOut",
        opacity: 0,
        bottom: "20%"
    }, { bottom: bottomTrigo1, x: 0, opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(trigo2, {
        ease: "power1.inOut",
        opacity: 0,
        bottom: "20%"
    }, { bottom: "10%", x: 0, opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(trigo3, {
        ease: "power1.inOut",
        opacity: 0,
        bottom: "20%"
    }, { bottom: bottomTrigo3, x: 0, opacity: 1, duration: 1 }, "-=1");
    animationTl.fromTo(bread3, {
        ease: "power1.inOut", bottom: "-10%",
    }, { bottom: bottomBread3, duration: 1 });
    animationTl.fromTo(bread4, {
        ease: "power1.inOut",
        bottom: "-20%",
    }, { bottom: bottomBread4, duration: 1 }, "-=1");

    ScrollTrigger.create({
        animation: animationTl,
        trigger: "#tg-crejochos",
        scrub: 1,
        pin: true,
        start: "top top",
        end: "+=500",
        markers: false,
        pinSpacing: false
    });
}