var listShops = {};
var map;
var markers = [];
var geocoder = new google.maps.Geocoder();
var gridResults = $('#content-results');
var radius_km = 5;
var radius_circle = new google.maps.Circle();

$(document).ready(function () {
    function initMap() {
        map = new google.maps.Map(document.getElementById('map'), {
            center: new google.maps.LatLng(20.5911359, -100.4038924),
            zoom: 11,
        });
        $.ajax({
            url: aj_ajax.ajaxurl,
            type: 'POST',
            data: {
                'action': 'actionGetShops',
            },
            success: function (resp) {
                let filterShops = JSON.parse(resp);
                filterShops = filterShops.filter(t => t.latitud && t.longitud);
                listShops = filterShops;
                inicializaMapa();
            },
            error: function (jqXHR, estado, error) {
            },
            complete: function (jqXHR, estado) {
            }
        });
    }
    initMap();
});

$("#formBusqueda").validate({
    rules: {
        direccion: "required",
    },
    messages: {
        direccion: "La dirección es requerida",
    },
    submitHandler: function (form, event) {
        event.preventDefault();
        filterTiendasMap();
    },
});

function filterTiendasMap() {
    let isvalid = $("#formBusqueda").valid();
    if (isvalid) {
        deleteMarkers();
        let value = $('input[name="direccion"]').val();
        $('#content-results').empty();
        $('#errorDireccion').hide();
        $('#content-results').removeClass("hidden");
        $('#notResultMaps').addClass("hidden");
        geocoder.geocode({ 'address': value, 'region': 'MX' }, function (results, status) {
            console.log(results);
            console.log(status);
            if (status == google.maps.GeocoderStatus.OK) {
                var location = results[0].geometry.location;
                var latitude = location.lat();
                var longitude = location.lng();
                radius_circle = new google.maps.Circle({
                    center: location,
                    radius: radius_km * 1000,
                    clickable: false,
                    map: map
                });
                radius_circle.setOptions({ fillOpacity: 0, strokeOpacity: 0 });
                if (radius_circle) {
                    map.fitBounds(radius_circle.getBounds());
                    showMarkers(location);
                }
            }else{
                $('#content-results').addClass("hidden");
                $('.container-filter').addClass("hidden");
                $('#form-results').removeClass("hidden");
                $('#notResultMaps').removeClass("hidden");
            }
        });
    }
}

$('#resetFilter').click(function (e) {
    e.preventDefault();
    $("#formBusqueda")[0].reset();
    $('.container-filter').removeClass("hidden");
    $('#form-results').addClass("hidden");
});

function inicializaMapa() {
    if (listShops.length > 0) {
        for (var t = 0; t < listShops.length; t++) {
            let tiendaObj = listShops[t];
            addMarker(tiendaObj);
        }
        checkMarkers();
    }
}

function addMarker(place) {
    var marker = new google.maps.Marker({
        position: new google.maps.LatLng(place.latitud, place.longitud),
        clickable: true,
        // label: place.nombre
    });
    google.maps.event.addListener(marker, 'click', function () {
        map.panTo(marker.getPosition());
        map.setZoom(20);
    });
    markers[place.id] = marker;
}

function checkMarkers() {
    for (var i = 0; i < listShops.length; i++) {
        var focus = map.getBounds().contains(markers[listShops[i].id].getPosition()); //Recorre todos los marcadores, y busca si coinciden con el area en focus
        if (focus) showElement(listShops[i].id); //Si está dentro de la zona enfocada, muestra el marcador
    };
}

function showElement(markerId) {
    markers[markerId].setMap(map);
}

function showMarkers(locationPlace) {
    if (listShops.length > 0) {
        let resultCount = 0;
        for (var c = 0; c < listShops.length; c++) {
            var marker_lat_lng = new google.maps.LatLng(listShops[c].latitud, listShops[c].longitud);
            var distance_from_location = google.maps.geometry.spherical.computeDistanceBetween(locationPlace, marker_lat_lng); //distance in meters between your location and the marker
            if (distance_from_location <= radius_km * 1000) {
                var tiendaObjet = listShops[c];
                addMarker(tiendaObjet);
                showElement(tiendaObjet.id);
                var htmlCard = `
                <a href="${tiendaObjet.linkGoogleMpas}" target="_blank" class="rounded-lg group border-grisOpaco px-6 py-8 md:px-8 lg:p-12 md:py-10 border bg-white flex flex-col sm:items-start">
                    <h4 class="text-azul mb-4 md:mb-6">${tiendaObjet.nombre}</h4>
                    <p class="parrafo text-grisMedio mb-6 lg:mb-8">${tiendaObjet.direccion}</p>
                    <button class="btn-outline group-hover:btn-outline-hover group-hover:borderbluehover group-hover:box-white-hover borderblue box-white justify-center font-button">
                        <span class="relative z-[1]">CÓMO LLEGAR</span>
                        <div class="ml-4 relative z-[1]">
                            <svg width="17" height="20" viewBox="0 0 17 20" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="m14.104 11.834-1.522 1.673h.168L8.788 18.41l-5.28-6.532-.02-.023-.02-.022c-1.052-1.155-1.68-2.641-1.68-4.262C1.786 3.993 4.866 1 8.785 1c3.919 0 7 2.993 7 6.571 0 1.62-.63 3.107-1.682 4.263z" stroke-width="2" />
                                <path d="M8.786 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6z" fill="#026C80" />
                            </svg>
                        </div>
                    </button>
                </a>
                `;
                gridResults.append(htmlCard);
                resultCount += 1;
            }
        }
        if(resultCount == 0){
            $('#content-results').addClass("hidden");
        }
        $('.container-filter').addClass("hidden");
        $('#form-results').removeClass("hidden");
    }
}

function setAllMap(map) {
    for (var i = 0; i < listShops.length; i++) {
        if (typeof markers[listShops[i].id] !== 'undefined') {
            markers[listShops[i].id].setMap(map);
        }
    }
}

function deleteMarkers() {
    radius_circle.setMap(null);
    clearMarkers();
    markers = [];
}

function clearMarkers() {
    setAllMap(null);
}